=======
History
=======

0.3.0 (2021-06-12)
------------------
* Release on PyPI as pyrato

0.2.1 (2020-02-26)
------------------

* Bugfix Chu's EDC calculation
* Documentation fixes
* Improved identification of impulse response onset

0.2.0 (2019-11-19)
------------------

* Energy decay curve calculation with various noise compensation methods
* Linear regression based reverberation time estimation

0.1.0 (2018-12-13)
------------------

* First release
